@@ -13,7 +13,10 @@ from ecs_composex.common import LOG
 from ecs_composex.common.aws import deploy, plan
 from ecs_composex.common.settings import ComposeXSettings
 from ecs_composex.common.stacks import process_stacks
-from ecs_composex.ecr.docker_opts import evaluate_docker_configs, evaluate_ecr_configs
+from ecs_composex.compose.compose_services.service_image.docker_opts import (
+    evaluate_docker_configs,
+    evaluate_ecr_configs,
+)
 from ecs_composex.ecs_composex import generate_full_template
 
 
