@@ -1,10 +1,9 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """Common Conditions across the templates"""
 
-from troposphere import Condition, Equals, If, Not, Ref
+from troposphere import Equals, If, Ref
 
 from ecs_composex.common import cfn_params
 
@@ -14,13 +13,6 @@ USE_STACK_NAME_CON = Equals(
 )
 
 
-USE_SPOT_CON_T = "UseSpotFleetHostsCondition"
-USE_SPOT_CON = Equals(Ref(cfn_params.USE_FLEET), "True")
-
-NOT_USE_SPOT_CON_T = "NotUseSpotFleetHostsCondition"
-NOT_USE_SPOT_CON = Not(Condition(USE_SPOT_CON_T))
-
-
 def pass_root_stack_name():
     """
     Function to add root_stack to a stack parameters
@@ -38,7 +30,7 @@ def pass_root_stack_name():
 
 def define_stack_name(template=None):
     """
-    Function to return Stack name contstruct.
+    Function to return Stack name construct.
     Adds the conditions and parameters if template is given.
 
     :param troposphere.Template template: the template to add it to.
