@@ -1,21 +1,107 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 import re
 
 from compose_x_common.compose_x_common import keyisset
-from troposphere import AWS_NO_VALUE, Ref
+from troposphere import AWS_NO_VALUE, GetAtt, Output, Ref, Sub
 from troposphere.ecs import LoadBalancer as EcsLb
-from troposphere.elasticloadbalancingv2 import Matcher, TargetGroupAttribute
+from troposphere.elasticloadbalancingv2 import (
+    Matcher,
+    TargetGroup,
+    TargetGroupAttribute,
+)
 
 from ecs_composex.common import LOG, add_outputs, add_parameters
+from ecs_composex.common.cfn_params import Parameter
 from ecs_composex.ecs.ecs_params import ELB_GRACE_PERIOD
-from ecs_composex.elbv2.elbv2_params import LB_SG_ID, TGT_GROUP_ARN
-from ecs_composex.elbv2.elbv2_stack import ComposeTargetGroup
+from ecs_composex.elbv2.elbv2_params import (
+    LB_SG_ID,
+    TGT_FULL_NAME,
+    TGT_GROUP_ARN,
+    TGT_GROUP_NAME,
+)
 from ecs_composex.vpc.vpc_params import VPC_ID
 
 
+class ComposeTargetGroup(TargetGroup):
+    """
+    Class to manage Target Groups
+    """
+
+    def __init__(self, title, elbv2, family, stack, **kwargs):
+        self.family = family
+        self.stack = stack
+        self.outputs = []
+        self.elbv2 = elbv2
+        self.output_properties = {}
+        self.attributes_outputs = {}
+        super().__init__(title, **kwargs)
+
+    def init_outputs(self):
+        self.output_properties = {
+            TGT_GROUP_ARN: (self.title, self, Ref, None),
+            TGT_GROUP_NAME: (
+                f"{self.title}{TGT_GROUP_NAME.return_value}",
+                self,
+                GetAtt,
+                TGT_GROUP_NAME.return_value,
+                None,
+            ),
+            TGT_FULL_NAME: (
+                f"{self.title}{TGT_FULL_NAME.return_value}",
+                self,
+                GetAtt,
+                TGT_FULL_NAME.return_value,
+                None,
+            ),
+        }
+
+    def generate_outputs(self):
+        for (
+            attribute_parameter,
+            output_definition,
+        ) in self.output_properties.items():
+            output_name = f"{self.title}{attribute_parameter.title}"
+            value = self.set_new_resource_outputs(output_definition)
+            self.attributes_outputs[attribute_parameter] = {
+                "Name": output_name,
+                "Output": Output(output_name, Value=value),
+                "ImportParameter": Parameter(
+                    output_name,
+                    return_value=attribute_parameter.return_value,
+                    Type=attribute_parameter.Type,
+                ),
+                "ImportValue": GetAtt(
+                    self.stack,
+                    f"Outputs.{output_name}",
+                ),
+                "Original": attribute_parameter,
+            }
+        for attr in self.attributes_outputs.values():
+            if keyisset("Output", attr):
+                self.outputs.append(attr["Output"])
+
+    def set_new_resource_outputs(self, output_definition):
+        """
+        Method to define the outputs for the resource when new
+        """
+        if output_definition[2] is Ref:
+            value = Ref(output_definition[1])
+        elif output_definition[2] is GetAtt:
+            value = GetAtt(output_definition[1], output_definition[3])
+        elif output_definition[2] is Sub:
+            value = Sub(output_definition[3])
+        else:
+            raise TypeError(
+                f"3rd argument for {output_definition[0]} must be one of",
+                (Ref, GetAtt, Sub),
+                "Got",
+                output_definition[2],
+            )
+        return value
+
+
 def validate_tcp_health_counts(props):
     healthy_prop = "HealthyThresholdCount"
     unhealthy_prop = "UnhealthyThresholdCount"
@@ -34,6 +120,11 @@ def validate_tcp_health_counts(props):
 
 
 def fix_nlb_settings(props):
+    """
+    Function to automatically adjust/correct settings for NLB to avoid users cringe on fails
+
+    :param dict props:
+    """
     network_modes = ["TCP", "UDP", "TCP_UDP"]
     if (
         keyisset("HealthCheckProtocol", props)
@@ -212,18 +303,21 @@ def handle_sg_lb_ingress_to_service(resource, family, resources_stack):
     """
     Function to add ingress from the LB to Target if using ALB
     :param resource:
-    :param family:
+    :param ecs_composex.ecs.ecs_family.ComposeFamily family:
     :param resources_stack:
     :return:
     """
     if resource.is_nlb():
         return
+    if resource.cfn_resource and not resource.attributes_outputs:
+        resource.init_outputs()
+        resource.generate_outputs()
     lb_sg_param = resource.attributes_outputs[LB_SG_ID]["ImportParameter"]
     add_parameters(family.template, [lb_sg_param])
-    family.service_config.network.add_lb_ingress(
-        family, lb_name=resource.logical_name, lb_sg_ref=Ref(lb_sg_param)
+    family.service_networking.add_lb_ingress(
+        lb_name=resource.logical_name, lb_sg_ref=Ref(lb_sg_param)
     )
-    family.stack_parameters.update(
+    family.stack.Parameters.update(
         {lb_sg_param.title: resource.attributes_outputs[LB_SG_ID]["ImportValue"]}
     )
     if resources_stack.title not in family.stack.DependsOn:
@@ -320,8 +414,8 @@ def import_target_group_attributes(props, target_def, elbv2, service):
 
 def define_service_target_group(
     resource,
-    service,
     family,
+    service,
     resources_root_stack,
     target_definition,
 ):
@@ -329,7 +423,7 @@ def define_service_target_group(
     Function to create the elbv2 target group
     :param ecs_composex.elbv2.elbv2_stack.Elbv2 resource: the ELBv2 to attach to
     :param ecs_composex.common.compose_services.ComposeService service: the service target
-    :param ecs_composex.common.compose_services.ComposeFamily family: the family owning the service
+    :param ecs_composex.ecs.ecs_family.ComposeFamily family: the family owning the service
     :param ecs_composex.common.stacks.ComposeXStack resources_root_stack:
     :param dict target_definition: the Service definition
     :return: the target group
@@ -347,22 +441,27 @@ def define_service_target_group(
     props["TargetType"] = "ip"
     import_target_group_attributes(props, target_definition, resource, service)
     validate_props_and_service_definition(props, service)
+    target_group_name = f"Tgt{resource.logical_name}{family.logical_name}{service.logical_name}{props['Port']}"
     target_group = ComposeTargetGroup(
-        f"Tgt{resource.logical_name}{family.logical_name}{service.logical_name}{props['Port']}",
+        target_group_name,
         elbv2=resource,
         family=family,
         stack=resource.stack,
         VpcId=Ref(VPC_ID),
         **props,
     )
+    if target_group.title not in resources_root_stack.stack_template.resources:
+        resources_root_stack.stack_template.add_resource(target_group)
+    else:
+        target_group = resources_root_stack.stack_template.resources[target_group.title]
     target_group.init_outputs()
     target_group.generate_outputs()
-    resources_root_stack.stack_template.add_resource(target_group)
-    resources_root_stack.stack_template.add_output(target_group.outputs)
-    family.target_groups.append(target_group)
+    add_outputs(resources_root_stack.stack_template, target_group.outputs)
+    if target_group not in family.target_groups:
+        family.target_groups.append(target_group)
     tgt_parameter = target_group.attributes_outputs[TGT_GROUP_ARN]["ImportParameter"]
     add_parameters(family.template, [tgt_parameter])
-    family.stack_parameters.update(
+    family.stack.Parameters.update(
         {
             tgt_parameter.title: target_group.attributes_outputs[TGT_GROUP_ARN][
                 "ImportValue"
@@ -374,7 +473,7 @@ def define_service_target_group(
         ContainerName=service.name,
         TargetGroupArn=Ref(tgt_parameter),
     )
-    family.ecs_service.ecs_service.LoadBalancers.append(service_lb)
+    family.ecs_service.lbs.append(service_lb)
     add_parameters(family.template, [ELB_GRACE_PERIOD])
     family.ecs_service.ecs_service.HealthCheckGracePeriodSeconds = Ref(ELB_GRACE_PERIOD)
     handle_sg_lb_ingress_to_service(resource, family, resources_root_stack)
@@ -383,8 +482,8 @@ def define_service_target_group(
 
 def define_service_target_group_definition(
     resource,
-    service,
     family,
+    service,
     target_def,
     resources_root_stack,
 ):
@@ -393,7 +492,7 @@ def define_service_target_group_definition(
 
     :param ecs_composex.elbv2.elbv2_stack.Elbv2 resource:
     :param service:
-    :param ecs_composex.common.compose_services.ComposeFamily family:
+    :param ecs_composex.ecs.ecs_family.ComposeFamily family:
     :param dict target_def:
     :param ecs_composex.common.stacks.ComposeXStack resources_root_stack:
     :return:
@@ -401,13 +500,13 @@ def define_service_target_group_definition(
     if resource.logical_name not in family.stack.DependsOn:
         family.stack.DependsOn.append(resources_root_stack.title)
         LOG.info(
-            f"Added dependency between service family {family.logical_name} and {resources_root_stack.title}"
+            f"{resource.module.res_key}.{resource.name} - Adding {family.logical_name} {service.name}"
         )
 
     service_tgt_group = define_service_target_group(
         resource,
-        service,
         family,
+        service,
         resources_root_stack,
         target_def,
     )
@@ -424,33 +523,35 @@ def handle_services_association(resource, res_root_stack, settings):
     :return:
     """
     template = res_root_stack.stack_template
-    stack = res_root_stack
     resource.set_listeners(template)
     resource.associate_to_template(template)
     add_outputs(template, resource.outputs)
     identified = []
     for target in resource.families_targets:
+        if target[1].launch_type == "EXTERNAL":
+            LOG.error(
+                f"x-elbv2.{resource.name} - Target family {target[0].name} uses EXTERNAL launch type. Ignoring"
+            )
+            continue
         tgt_arn = define_service_target_group_definition(
             resource, target[0], target[1], target[2], res_root_stack
         )
         for service in resource.services:
-            target_name = f"{target[1].name}:{target[0].name}"
+            target_name = f"{target[0].name}:{target[1].name}"
             if target_name == service["name"]:
                 service["target_arn"] = tgt_arn
                 identified.append(True)
-    if not identified or not (identified and all(identified)):
-        raise LookupError(
-            "Failed to define a TGT Group for any of",
-            [target[0].name for target in resource.families_targets],
-            "and map it for LB",
-            resource.name,
+    if not identified:
+        LOG.error(
+            f"{resource.module.res_key}.{resource.name} - No services found as targets. Skipping association"
         )
+        return
 
     for listener in resource.listeners:
-        listener.map_services(resource)
+        listener.map_lb_services_to_listener_targets(resource)
     for listener in resource.listeners:
-        listener.handle_certificates(settings, stack)
-        listener.handle_cognito_pools(settings, stack)
+        listener.handle_certificates(settings, res_root_stack)
+        listener.handle_cognito_pools(settings, res_root_stack)
         listener.define_default_actions(template)
 
 
@@ -464,8 +565,7 @@ def elbv2_to_ecs(resources, services_stack, res_root_stack, settings):
     :param ecs_composex.common.settings.ComposeXSettings settings:
     :return:
     """
-    new_resources = [
-        resources[res_name] for res_name in resources if not resources[res_name].lookup
-    ]
-    for resource in new_resources:
-        handle_services_association(resource, res_root_stack, settings)
+    for resource_name, resource in resources.items():
+        LOG.info(f"{resource.module.res_key}.{resource_name} - Linking to services")
+        if resource.cfn_resource and not resource.mappings:
+            handle_services_association(resource, res_root_stack, settings)
